==> 0.9.6-1.tar.gz: mucommander-0.9.6-1/mucommander-format-tar/src/main/java/com/mucommander/commons/file/archive/tar/TarFormatProvider.java <==
/**
 * This file is part of muCommander, http://www.mucommander.com
 *
 * muCommander is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * muCommander is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


package com.mucommander.commons.file.archive.tar;

import com.mucommander.commons.file.AbstractFile;
import com.mucommander.commons.file.archive.AbstractArchiveFile;
import com.mucommander.commons.file.archive.ArchiveFormatProvider;
import com.mucommander.commons.file.filter.ExtensionFilenameFilter;
import com.mucommander.commons.file.filter.FilenameFilter;

import java.io.IOException;
import java.util.Arrays;
import java.util.List;

/**
 * This class is the provider for the 'Tar' archive format implemented by {@link TarArchiveFile}.
 *
 * @see com.mucommander.commons.file.archive.tar.TarArchiveFile
 * @author Nicolas Rinaudo, Maxence Bernard
 */
public class TarFormatProvider implements ArchiveFormatProvider {

    /** extensions of archive filenames */
    public static final String[] EXTENSIONS = new String[] {".tar", ".tar.gz", ".tgz", ".tar.bz2", ".tbz2", ".cbt", ".ova"};

    @Override
    public AbstractArchiveFile getFile(AbstractFile file) throws IOException {
        return new TarArchiveFile(file);
    }

    @Override
    public FilenameFilter getFilenameFilter() {
        return new ExtensionFilenameFilter(EXTENSIONS);
    }

    @Override
	public List<String> getExtensions() {
		return Arrays.asList(EXTENSIONS);
	}
}

==> 1.1.0-1.tar.gz: mucommander-1.1.0-1/mucommander-format-tar/src/main/java/com/mucommander/commons/file/archive/tar/TarFormatProvider.java <==
/**
 * This file is part of muCommander, http://www.mucommander.com
 *
 * muCommander is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * muCommander is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


package com.mucommander.commons.file.archive.tar;

import com.mucommander.commons.file.AbstractFile;
import com.mucommander.commons.file.archive.AbstractArchiveFile;
import com.mucommander.commons.file.archive.ArchiveFormatProvider;
import com.mucommander.commons.file.filter.ExtensionFilenameFilter;
import com.mucommander.commons.file.filter.FilenameFilter;

import java.io.IOException;
import java.util.Arrays;
import java.util.List;

/**
 * This class is the provider for the 'Tar' archive format implemented by {@link TarArchiveFile}.
 *
 * @see com.mucommander.commons.file.archive.tar.TarArchiveFile
 * @author Nicolas Rinaudo, Maxence Bernard
 */
public class TarFormatProvider implements ArchiveFormatProvider {

    /** extensions of archive filenames */
    public static final String[] EXTENSIONS = new String[] {".tar", ".cbt", ".ova"};

    @Override
    public AbstractArchiveFile getFile(AbstractFile file) throws IOException {
        return new TarArchiveFile(file);
    }

    @Override
    public FilenameFilter getFilenameFilter() {
        return new ExtensionFilenameFilter(EXTENSIONS);
    }

    @Override
	public List<String> getExtensions() {
		return Arrays.asList(EXTENSIONS);
	}
}
